==> apache-cloudstack-4.19.3.0-src.tar.bz2: apache-cloudstack-4.19.3.0-src/api/src/test/java/org/apache/cloudstack/api/command/admin/offering/CreateServiceOfferingCmdTest.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.cloudstack.api.command.admin.offering;

import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.runners.MockitoJUnitRunner;
import org.springframework.test.util.ReflectionTestUtils;

@RunWith(MockitoJUnitRunner.class)
public class CreateServiceOfferingCmdTest {

    @InjectMocks
    private CreateServiceOfferingCmd createServiceOfferingCmd;

    @Test
    public void testGetDisplayTextWhenEmpty() {
        String netName = "net-offering";
        ReflectionTestUtils.setField(createServiceOfferingCmd, "serviceOfferingName", netName);
        Assert.assertEquals(createServiceOfferingCmd.getDisplayText(), netName);
    }

}

==> apache-cloudstack-4.20.2.0-src.tar.bz2: apache-cloudstack-4.20.2.0-src/api/src/test/java/org/apache/cloudstack/api/command/admin/offering/CreateServiceOfferingCmdTest.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.cloudstack.api.command.admin.offering;

import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.junit.MockitoJUnitRunner;
import org.springframework.test.util.ReflectionTestUtils;

@RunWith(MockitoJUnitRunner.class)
public class CreateServiceOfferingCmdTest {

    @InjectMocks
    private CreateServiceOfferingCmd createServiceOfferingCmd;

    @Test
    public void testGetDisplayTextWhenEmpty() {
        String netName = "net-offering";
        ReflectionTestUtils.setField(createServiceOfferingCmd, "serviceOfferingName", netName);
        Assert.assertEquals(createServiceOfferingCmd.getDisplayText(), netName);
    }

    @Test
    public void testIsPurgeResourcesNoOrNullValue() {
        Assert.assertFalse(createServiceOfferingCmd.isPurgeResources());
        ReflectionTestUtils.setField(createServiceOfferingCmd, "purgeResources", false);
        Assert.assertFalse(createServiceOfferingCmd.isPurgeResources());
    }

    @Test
    public void testIsPurgeResourcesFalse() {
        ReflectionTestUtils.setField(createServiceOfferingCmd, "purgeResources", false);
        Assert.assertFalse(createServiceOfferingCmd.isPurgeResources());
    }

    @Test
    public void testIsPurgeResourcesTrue() {
        ReflectionTestUtils.setField(createServiceOfferingCmd, "purgeResources", true);
        Assert.assertTrue(createServiceOfferingCmd.isPurgeResources());
    }
}
